@@ -25,12 +25,12 @@ func init() {
 		"autocomplete":          "Set definitions for tab-completion in the command line",
 		"bexists":               "Check which builtins exist",
 		"bg":                    "Run processes in the background",
-		"break":                 "terminate execution of a block within your processes scope",
+		"break":                 "Terminate execution of a block within your processes scope",
 		"cast":                  "Alters the data type of the previous function without altering it's output",
 		"catch":                 "Handles the exception code raised by `try` or `trypipe",
 		"cd":                    "Change (working) directory",
 		"config":                "Query or define Murex runtime settings",
-		"continue":              "terminate process of a block within a caller function",
+		"continue":              "Terminate process of a block within a caller function",
 		"count":                 "Count items in a map, list or array",
 		"cpuarch":               "Output the hosts CPU architecture",
 		"cpucount":              "Output the number of CPU cores available on your host",
@@ -100,7 +100,9 @@ func init() {
 		"rand":                  "Random field generator",
 		"read":                  "`read` a line of input from the user and store as a variable",
 		"regexp":                "Regexp tools for arrays / lists of strings",
+		"return":                "Exits current function scope",
 		"right":                 "Right substring every item in a list",
+		"round":                 "Round a number by a user defined precision",
 		"runmode":               "Alter the scheduler's behaviour at higher scoping level",
 		"runtime":               "Returns runtime information on the internal state of Murex",
 		"rx":                    "Regexp pattern matching for file system objects (eg `.*\\\\.txt`)",
@@ -271,8 +273,10 @@ func init() {
 		"regexp":                "regexp",
 		"!regexp":               "regexp",
 		"list.regex":            "regexp",
+		"return":                "return",
 		"right":                 "right",
 		"list.right":            "right",
+		"round":                 "round",
 		"runmode":               "runmode",
 		"runtime":               "runtime",
 		"builtins":              "runtime",
